@@ -19,7 +19,9 @@
  */
 
 
-char * arg_names [] = { (char*)0, (char*)0, "STRING", "INT", "SHORT", "LONG", "FLOAT", "DOUBLE", "LONGDOUBLE", "LONGLONG" };
+#include "argsdef.h"
 
-char * arg_types [] = { (char*)0, "int", "char *", "int", "short", "long", "float", "double", "long double", "long long" };
+const char * arg_names [] = { (const char*)0, (const char*)0, "STRING", "INT", "SHORT", "LONG", "FLOAT", "DOUBLE", "LONGDOUBLE", "LONGLONG" };
+
+const char * arg_types [] = { (const char*)0, "int", "char *", "int", "short", "long", "float", "double", "long double", "long long int" };
 
