@@ -20,5 +20,9 @@
 #define GROUP_UNDEFINED 5
 #define INVALID_DEFAULT_VALUE 6
 #define NOT_REQUESTED_TYPE 7
+#define NOT_VALID_SPECIFICATION 8
+#define SPECIFY_FLAG_STAT 9
+#define NOT_GROUP_OPTION 10
+#define SPECIFY_GROUP 11
 
 #endif
