@@ -15,6 +15,7 @@ This file is licensed to you under the license specified in the included file
 #include <iostream>
 
 #include "acceptedvalues.h"
+#include "argsdef.h"
 
 struct gengetopt_option
 {
@@ -31,11 +32,29 @@ struct gengetopt_option
   char * group_desc; /* group description, if it's part of an option group */
   bool multiple; /* whether this option can be given more than once */
   bool arg_is_optional; /* whether the argument is optional */
+  bool hidden; /* whether this option will be hidden from the help output */
   char *type_str; /* Alternative name for type,
                      e.g. "URL" or "SECONDS" */
   const AcceptedValues *acceptedvalues; /* values that can be passed to this option */
   char *section; /* the section of this option */
   char *section_desc; /* the description associated with the possible section */
+  char *dependon; /* the name of the option this one depends on */
+  
+  /* parser information */
+  char *filename; /* source file */
+  int linenum; /* line number */
+  
+  gengetopt_option() :
+    short_opt(0), long_opt(0), desc(0), type(ARG_NO),
+    flagstat(-1),
+    required(1), var_arg(0), default_string(0),
+    group_value(0), group_desc(0),
+    multiple(false), arg_is_optional(false), hidden(false),
+    type_str(0), acceptedvalues(0),
+    section(0), section_desc(0), dependon(0),
+    filename(0), linenum(0)
+    {
+    }
 };
 
 typedef std::list<gengetopt_option *> gengetopt_option_list;
