@@ -41,33 +41,34 @@ extern "C"
 #include "my_sstream.h"
 
 #include "groups.h"
-#include "update_arg.h"
-#include "option_arg.h"
-#include "required_option.h"
-#include "generic_option.h"
-#include "group_option.h"
-#include "group_counter.h"
-#include "generic_option_group.h"
-#include "handle_help.h"
-#include "handle_version.h"
-#include "print_help_string.h"
-#include "multiple_opt_list.h"
-#include "multiple_opt_struct.h"
-#include "multiple_option.h"
-#include "multiple_fill_array.h"
-#include "multiple_fill_array_default.h"
-#include "free_string.h"
-#include "free_multiple.h"
-#include "free_inputs_string.h"
-#include "reset_group.h"
-#include "exit_failure.h"
-#include "update_given.h"
-#include "given_field.h"
-#include "clear_given.h"
-#include "clear_arg.h"
-#include "free_list.h"
-#include "file_save.h"
-#include "file_save_multiple.h"
+#include "skels/update_arg.h"
+#include "skels/option_arg.h"
+#include "skels/required_option.h"
+#include "skels/dependant_option.h"
+#include "skels/generic_option.h"
+#include "skels/group_option.h"
+#include "skels/group_counter.h"
+#include "skels/generic_option_group.h"
+#include "skels/handle_help.h"
+#include "skels/handle_version.h"
+#include "skels/print_help_string.h"
+#include "skels/multiple_opt_list.h"
+#include "skels/multiple_opt_struct.h"
+#include "skels/multiple_option.h"
+#include "skels/multiple_fill_array.h"
+#include "skels/multiple_fill_array_default.h"
+#include "skels/free_string.h"
+#include "skels/free_multiple.h"
+#include "skels/free_inputs_string.h"
+#include "skels/reset_group.h"
+#include "skels/exit_failure.h"
+#include "skels/update_given.h"
+#include "skels/given_field.h"
+#include "skels/clear_given.h"
+#include "skels/clear_arg.h"
+#include "skels/free_list.h"
+#include "skels/file_save.h"
+#include "skels/file_save_multiple.h"
 #include "gm_utils.h"
 #include "fileutils.h"
 
@@ -196,7 +197,7 @@ CmdlineParserCreator::CmdlineParserCreator (char *function_name,
   set_multiple_token_functions(has_multiple_options_with_type());
   set_multiple_token_vars(has_multiple_options_with_type());
   set_handle_unamed(unamed_options);
-  set_check_required_options(has_required());
+  set_check_required_options(has_required() || has_dependencies());
   set_has_purpose((gengetopt_purpose != 0));
   set_purpose(generate_purpose());
   set_no_package((gengetopt_package == 0));
@@ -216,7 +217,8 @@ void
 CmdlineParserCreator::do_update_arg (struct gengetopt_option *opt,
                                      ostream &stream,
                                      unsigned int indent,
-                                     const string argstr = "optarg" )
+                                     const string argstr = "optarg",
+                                     const string orig_argstr = "optarg")
 {
   if (opt->type == ARG_NO)
     {
@@ -229,6 +231,7 @@ CmdlineParserCreator::do_update_arg (struct gengetopt_option *opt,
 
   update_arg_gen_class update_arg_gen;
   update_arg_gen.set_optarg(argstr);
+  update_arg_gen.set_orig_optarg(orig_argstr);
   update_arg_gen.set_opt_var (opt->var_arg);
 
   if (opt->multiple)
@@ -250,6 +253,7 @@ CmdlineParserCreator::do_update_arg (struct gengetopt_option *opt,
           str_gen_null.set_no_free(true);
           str_gen_null.set_has_arg(true);
           str_gen_null.set_optarg ("NULL");
+          str_gen_null.set_orig_optarg ("NULL");
           str_gen_null.set_structure (string (opt->var_arg) + "_new");
           str_gen_null.set_opt_var (opt->var_arg);
           str_gen_null.generate_update_arg (stream, indent);
@@ -312,6 +316,9 @@ CmdlineParserCreator::do_update_arg (struct gengetopt_option *opt,
       abort ();
     }
 
+    update_arg_gen.set_package_var_name (EXE_NAME);
+    update_arg_gen.set_numeric(is_numeric(opt));
+    
   update_arg_gen.generate_update_arg (stream, indent);
 
   if (opt->arg_is_optional)
@@ -540,7 +547,7 @@ CmdlineParserCreator::generate_usage_string(bool use_config_package)
   if ( long_help )
     {
       foropt
-        if (opt->required) /* required options */
+        if (opt->required && !opt->hidden) /* required options */
           switch (opt->type) {
           case ARG_INT:
           case ARG_SHORT:
@@ -569,7 +576,7 @@ CmdlineParserCreator::generate_usage_string(bool use_config_package)
             abort ();
           }
       foropt
-        if (!opt->required)
+        if (!opt->required && !opt->hidden)
           switch (opt->type) {
           case ARG_NO:
           case ARG_FLAG:
@@ -699,6 +706,9 @@ CmdlineParserCreator::generate_help_option_list()
   /* calculate columns */
   desc_col = 0;
   foropt {
+    if (opt->hidden)
+        continue;
+    
     int width = 2 + 4 + 2;  // ws + "-a, " + ws
 
     width += strlen (opt->long_opt) + 2;  // "--"
@@ -732,6 +742,9 @@ CmdlineParserCreator::generate_help_option_list()
 
   foropt
     {
+      if (opt->hidden)
+        continue;  
+      
       if (opt->group_value &&
           (! prev_group || strcmp (opt->group_value, prev_group) != 0))
         {
@@ -1298,7 +1311,13 @@ CmdlineParserCreator::handle_options(ostream &stream, unsigned int indent, bool
 
               if (opt->type)
                 { // arguments possibly exists
-                  do_update_arg (opt, str_stream, 0, tmpvar);
+                    if (opt->acceptedvalues != 0) {
+                        // we take the argument from the vector of values
+                        string optarg_ = OPTION_VALUES_NAME(opt->var_arg) + "[found]";
+                        do_update_arg (opt, str_stream, 0, optarg_, tmpvar);
+                    } else {
+                        do_update_arg (opt, str_stream, 0, tmpvar, tmpvar);
+                    }
                   multip_opt_gen.set_option_has_type(true);
 
                   multip_opt_gen.set_update_arg(str_stream.str());
@@ -1315,9 +1334,6 @@ CmdlineParserCreator::handle_options(ostream &stream, unsigned int indent, bool
               else
                 multip_opt_gen.set_option_has_group(false);
 
-              multip_opt_gen.set_option_not_string(opt->type != ARG_STRING);
-              // for strings multi_token is copied directly, so it must not be freed.
-
               multip_opt_gen.generate_multiple_option (stream, indent);
             }
           else
@@ -1346,7 +1362,13 @@ CmdlineParserCreator::handle_options(ostream &stream, unsigned int indent, bool
               else
                 option_gen.set_update_group_count ("");
 
-              do_update_arg (opt, update_stream, 0);
+              if (opt->acceptedvalues != 0) {
+                  // we take the argument from the vector of values
+                  string optarg_ = OPTION_VALUES_NAME(opt->var_arg) + "[found]";
+                  do_update_arg (opt, update_stream, 0, optarg_, optarg);
+              } else {
+                  do_update_arg (opt, update_stream, 0);
+              }
 
               option_gen.set_update_arg(update_stream.str());
 
@@ -1465,6 +1487,37 @@ CmdlineParserCreator::generate_handle_required(ostream &stream,
   }
 }
 
+void
+CmdlineParserCreator::generate_handle_dependencies(ostream &stream,
+                                               unsigned int indent)
+{
+  struct gengetopt_option * opt;
+  dependant_option_gen_class opt_gen;
+  opt_gen.set_package_var_name ("prog_name");
+  string indent_str (indent, ' ');
+
+  /* write test for required options */
+  foropt
+    if ( opt->dependon )
+      {
+        stream << indent_str;
+
+        ostringstream req_opt;
+        req_opt << "'--" << opt->long_opt << "'";
+        if (opt->short_opt)
+          req_opt << " ('-" << opt->short_opt << "')";
+
+        opt_gen.set_option_var_name (opt->var_arg);
+        opt_gen.set_dep_option (canonize_name(opt->dependon));
+        opt_gen.set_option_descr (req_opt.str ());
+        opt_gen.set_dep_option_descr (opt->dependon);
+
+        opt_gen.generate_dependant_option (stream, indent);
+
+        stream << endl;
+      }
+}
+
 void
 CmdlineParserCreator::generate_group_counters(ostream &stream,
                                               unsigned int indent)
