@@ -21,8 +21,8 @@
 #ifndef _GM_H
 #define _GM_H
 
-#include "header.h"
-#include "c_source.h"
+#include "skels/header.h"
+#include "skels/c_source.h"
 
 #include <list>
 #include <string>
@@ -73,7 +73,8 @@ class CmdlineParserCreator : public header_gen_class, public c_source_gen_class
     }
 
   void do_update_arg (struct gengetopt_option *opt,
-                      ostream &stream, unsigned int indent, const string argstr );
+                      ostream &stream, unsigned int indent, const string argstr,
+                      const string orig_argstr);
   void free_option(struct gengetopt_option *opt,
                    ostream &stream, unsigned int indent);
 
@@ -98,6 +99,7 @@ class CmdlineParserCreator : public header_gen_class, public c_source_gen_class
                                                unsigned int indent);
   virtual void generate_handle_option(ostream &stream, unsigned int indent);
   virtual void generate_handle_required(ostream &stream, unsigned int indent);
+  virtual void generate_handle_dependencies(ostream &stream, unsigned int indent);
   virtual void generate_handle_group(ostream &stream, unsigned int indent);
   virtual void generate_group_counters(ostream &stream, unsigned int indent);
   virtual void generate_handle_version(ostream &stream, unsigned int indent);
