@@ -145,6 +145,20 @@ has_required()
   return false;
 }
 
+bool
+has_dependencies()
+{
+  struct gengetopt_option * opt = 0;
+
+  foropt
+  {
+    if (opt->dependon)
+      return true;
+  }
+
+  return false;
+}
+
 bool
 has_options()
 {
@@ -265,3 +279,20 @@ wrap_cstr( string& wrapped, unsigned int from_column, unsigned int second_indent
 
   wrapped += stream.str();
 }
+
+bool is_numeric(const gengetopt_option *opt)
+{
+    switch (opt->type)
+    {
+        case ARG_INT:
+        case ARG_SHORT:
+        case ARG_LONG:
+        case ARG_FLOAT:
+        case ARG_DOUBLE:
+        case ARG_LONGDOUBLE:
+        case ARG_LONGLONG:
+            return true;
+        default:
+            return false;
+    }
+}
