@@ -15,6 +15,8 @@
 
 #include <string>
 
+#include "ggos.h"
+
 using std::string;
 
 char *canonize_names(const char * name);
@@ -26,9 +28,18 @@ bool has_multiple_options_string();
 bool has_multiple_options();
 bool has_multiple_options_with_type();
 bool has_required();
+bool has_dependencies();
 bool has_options();
 bool has_values();
 
+/**
+ * Whether the specified option deals with number
+ * 
+ * @param opt 
+ * @return 
+ */
+bool is_numeric(const gengetopt_option *opt);
+
 void wrap_cstr (string &wrapped, unsigned int from_column, unsigned int second_indent, const string &orig);
 
 #endif
