@@ -49,10 +49,12 @@
      TOK_SECTION = 275,
      TOK_SECTIONDESC = 276,
      TOK_VALUES = 277,
-     TOK_STRING = 278,
-     TOK_MLSTRING = 279,
-     TOK_CHAR = 280,
-     TOK_ARGTYPE = 281
+     TOK_HIDDEN = 278,
+     TOK_DEPENDON = 279,
+     TOK_STRING = 280,
+     TOK_MLSTRING = 281,
+     TOK_CHAR = 282,
+     TOK_ARGTYPE = 283
    };
 #endif
 #define TOK_PACKAGE 258
@@ -75,25 +77,28 @@
 #define TOK_SECTION 275
 #define TOK_SECTIONDESC 276
 #define TOK_VALUES 277
-#define TOK_STRING 278
-#define TOK_MLSTRING 279
-#define TOK_CHAR 280
-#define TOK_ARGTYPE 281
+#define TOK_HIDDEN 278
+#define TOK_DEPENDON 279
+#define TOK_STRING 280
+#define TOK_MLSTRING 281
+#define TOK_CHAR 282
+#define TOK_ARGTYPE 283
 
 
 
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 80 "parser.yy"
+#line 97 "parser.yy"
 typedef union YYSTYPE {
     char   *str;
     char    chr;
     int	    argtype;
     int	    boolean;
     class AcceptedValues *ValueList;
+    struct gengetopt_option *gengetopt_option;
 } YYSTYPE;
 /* Line 1285 of yacc.c.  */
-#line 97 "parser.h"
+#line 102 "parser.h"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -101,5 +106,19 @@ typedef union YYSTYPE {
 
 extern YYSTYPE yylval;
 
+#if ! defined (YYLTYPE) && ! defined (YYLTYPE_IS_DECLARED)
+typedef struct YYLTYPE
+{
+  int first_line;
+  int first_column;
+  int last_line;
+  int last_column;
+} YYLTYPE;
+# define yyltype YYLTYPE /* obsolescent; will be withdrawn */
+# define YYLTYPE_IS_DECLARED 1
+# define YYLTYPE_IS_TRIVIAL 1
+#endif
+
+extern YYLTYPE yylloc;
 
 
