@@ -16,10 +16,10 @@ main (int argc, char **argv)
 {  
   /* do not override command line options, initialize args_info */
   if (test_conf_parser_cmd_parser_configfile
-      ("./test_conf2.conf", &args_info, 0, 1) != 0)
+      ("./test_conf2.conf", &args_info, 0, 1, 0) != 0)
     exit(1);
 
-  if (test_conf_parser_cmd_parser2 (argc, argv, &args_info, 1, 0) != 0)
+  if (test_conf_parser_cmd_parser2 (argc, argv, &args_info, 1, 0, 1) != 0)
     exit(1) ;
 
   printf ("value of required: %s\n", args_info.required_arg);
